==> HorizonJPL-0.1.1.tar.gz: HorizonJPL-0.1.1/horizon/test/test_horizon.py <==
# python-jpl-horizon
#
# Written by: Matthew Mihok (@mattmattmatt)
#
# The MIT License (MIT)
# Copyright (c) 2013
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to permit
# persons to whom the Software is furnished to do so, subject to the
# following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

import unittest
import pytest

from horizon.interface import Interface


class TestHorizonInterface(unittest.TestCase):
    # print "Running Tests..."

    def setUp(self):
        self.horizon = Interface()

    @pytest.mark.timeout(10)
    def test_connection(self):
        version = self.horizon.version()

        self.assertTrue(version)

    @pytest.mark.timeout(300)
    def test_minor_bodies(self):
        data = self.horizon.minor()

        self.assertTrue(len(data))

    @pytest.mark.timeout(10)
    def test_major_bodies(self):
        data = self.horizon.major()

        self.assertTrue(len(data))

    @pytest.mark.timeout(10)
    def test_get(self):
        data = self.horizon.get(100)

        self.assertTrue(data)

==> HorizonJPL-0.1.6.tar.gz: HorizonJPL-0.1.6/horizon/test/test_horizon.py <==
# python-jpl-horizon
#
# Written by: Matthew Mihok (@mattmattmatt)
#
# The MIT License (MIT)
# Copyright (c) 2013
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to permit
# persons to whom the Software is furnished to do so, subject to the
# following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

import unittest
import pytest

from horizon.interface import Interface


class TestHorizonInterface(unittest.TestCase):
    # print "Running Tests..."

    def setUp(self):
        self.horizon = Interface()

    @pytest.mark.timeout(10)
    def test_connection(self):
        version = self.horizon.get_version()

        self.assertTrue(version)

    @pytest.mark.timeout(300)
    def test_minor_bodies(self):
        data = self.horizon.get_minor()

        self.assertTrue(len(data))

    @pytest.mark.timeout(10)
    def test_major_bodies(self):
        data = self.horizon.get_major()

        self.assertTrue(len(data))

    @pytest.mark.timeout(10)
    def test_get(self):
        data = self.horizon.get(10)

        self.assertTrue(data)
